This function is makes the blocked mapping function.
Usage
Construct.H.multisite(site.ids, var.names, obs.t.mean, products = NULL)
Arguments
- site.ids
a vector name of site ids
- var.names
vector names of state variable names
- obs.t.mean
list of vector of means for the time t for different sites.
- products
vector names of products for each observation.
Value
Returns a matrix with block sizes determined by the b argument. Each block is filled with the same value taken from x.