Skip to contents

This function is an upgrade to the Construct.H.multisite function which provides the index by different criteria.

Usage

construct_nimble_H(
  site.ids,
  var.names,
  obs.t,
  pft.path = NULL,
  by = "single",
  products = NULL
)

Arguments

site.ids

a vector name of site ids

var.names

vector names of state variable names

obs.t

list of vector of means for the time t for different sites.

pft.path

physical path to the pft.csv file.

by

criteria, it supports by variable, site, pft, all, and single Q.

products

vector names of products for each observation.

Value

Returns one vector containing index for which Q to be estimated for which variable, and the other vector gives which state variable has which observation (= element.W.Data).

Author

Dongchen Zhang