Skip to contents

This function helps to extract the covariates based on date and coordinates from the settings object.

Usage

debias.extract.cov(cov.dir, date, site.info)

Arguments

cov.dir

character: physical path to the directory contains the time series covariate maps.

date

numeric or character: date that used to find the corresponding covariate file.

site.info

data.frame: data.frame that contains longitude and latitude in its first and second column.

Value

data.frame: a data frame containing M (rows) of locations across N (columns) variables.

Author

Dongchen Zhang