Skip to contents

This function helps to create the mapping operator that maps between product names and variable names by locations.

Usage

debias.map.products(obs.mean.t, obs_prep)

Arguments

obs.mean.t

list: lists of sites that contain observations for each variable.

obs_prep

list: lists contains basic information for each product of each observation.

Value

matrix: a matrix containing M (rows) of locations*variables across N (columns) products.

Author

Dongchen Zhang