Skip to contents

This function performs a simple outlier replacement on all the columns of dataframes inside a list

Usage

outlier_detector_boxplot(X)

Arguments

X

A list of dataframes

Value

A list the same dimension as X, with each column of each dataframe modified by replacing outlier points with the column median