Skip to contents

Subset ensemble data for downscaling

Usage

subset_ensemble(ensemble_data, site_coords, date, carbon_pool)

Arguments

ensemble_data

EFI standard tibble or data.frame

site_coords

A data.frame with a unique `site_id` column.

date

Date. The date for the run, must be a date within `ensemble_data`.

carbon_pool

Character. Carbon pool of interest. Name must match a value in `ensemble_data$variable`.

Value

A data.frame containing `site_id`, `ensemble`, and `prediction` for the specified date and carbon pool.

Details

This function subsets ensemble data and ensures that the specified date and carbon pool are present in the ensemble data.

Author

Sambhav Dixit, David LeBauer