This function helps to calculate the residual error for a certain time point and variable.
Arguments
- obs.mean
List: lists of date times named by time points, which contains lists of sites named by site ids, which contains observation means for each state variables of each site for each time point.
- all.X
list: lists of data frame of model forecast from the beginning to the current time points that has n (ensemble size) rows and n.var (number of variables) times n.site (number of locations) columns. (e.g., 100 ensembles, 4 variables, and 8,000 locations will end up with data.frame of 100 rows and 32,000 columns).
- t
numeric: the current number of time points (e.g., t=1 for the beginning time point).
- var.name
character: variable name to be predicted.
- data.source
character: product name of the data.