Ensemble Downscale
Arguments
- ensemble_data
EFI standard tibble or data.frame. Contains carbon data for downscaling.
- site_coords
data.frame, tibble, or sf object. Design points. If not sf object, must have 'lon' and 'lat' columns. Must have a unique `site_id` field.
- covariates
table containing numeric predictors to be used in downscaling. Must have unique identifier 'site_id' field and predictor attributes
Value
A list containing the model, predictions for all values of covariates as well as test data and test predictions for downstream statistics.